@@ -4,7 +4,7 @@ use warnings;
 
 use base qw/Class::Data::Inheritable/;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 __PACKAGE__->mk_classdata( namespace_regex       => undef );
 __PACKAGE__->mk_classdata( ignore_class_regex    => undef );
@@ -113,6 +113,17 @@ use Term::ANSIColor;
     );
 };
 
+'Furl::HTTP'->require and do {
+    __PACKAGE__->add_prof(
+        'Furl::HTTP',
+        'request',
+        sub {
+            my($orig, $self, %args) = @_;
+            return sprintf '%s %s', $args{method}, $args{url};
+        },
+    );
+};
+
 sub add_profs {
     my ($class, $module, $methods, $callback) = @_;
     $module->require; # or warn $@ and return;
